@@ -1,6 +1,7 @@
 /*
  *  GNOME Logs - View and search logs
  *  Copyright (C) 2013  Red Hat, Inc.
+ *  Copyright (C) 2015  Ekaterina Gerasimova
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,6 +21,18 @@
 
 #include <glib/gi18n.h>
 
+/**
+ * GlUtilTimestamps:
+ * @GL_UTIL_TIMESTAMPS_SAME_DAY: the timestamps have the same year, month and
+ * day
+ * @GL_UTIL_TIMESTAMPS_SAME_YEAR: the timestamps have the same year, but
+ * different months and days
+ * @GL_UTIL_TIMESTAMPS_DIFFERENT_YEAR: the timestamps have different years,
+ * months and days
+ *
+ * Date string comparison result, used for formatting a date into an
+ * appropriate string.
+ */
 typedef enum
 {
     GL_UTIL_TIMESTAMPS_SAME_DAY,
@@ -27,6 +40,16 @@ typedef enum
     GL_UTIL_TIMESTAMPS_DIFFERENT_YEAR
 } GlUtilTimestamps;
 
+/**
+ * gl_util_on_css_provider_parsing_error:
+ * @provider: the provider that had a parsing error
+ * @section: section the error happened in
+ * @error: the parsing error
+ * @user_data: user data set when the signal handler was connected
+ *
+ * Handle the GtkCssProvider::parsing-error signal and print a warning based on
+ * @section and @error.
+ */
 void
 gl_util_on_css_provider_parsing_error (GtkCssProvider *provider,
                                        GtkCssSection *section,
@@ -39,6 +62,15 @@ gl_util_on_css_provider_parsing_error (GtkCssProvider *provider,
                 error->message);
 }
 
+/**
+ * compare_timestamps:
+ * @a: a date
+ * @b: a date to compare with
+ *
+ * Compare @a to @b and return how similar the dates are.
+ *
+ * Returns: a value from GlUtilTimestamps
+ */
 static GlUtilTimestamps
 compare_timestamps (GDateTime *a,
                     GDateTime *b)
@@ -64,13 +96,25 @@ compare_timestamps (GDateTime *a,
     return GL_UTIL_TIMESTAMPS_SAME_YEAR;
 }
 
+/**
+ * gl_util_timestamp_to_display:
+ * @microsecs: number of microseconds since the Unix epoch in UTC
+ * @now: the time to compare with
+ * @format: clock format (12 or 24 hour)
+ *
+ * Return a human readable time, corresponding to @microsecs, using an
+ * appropriate @format after comparing it to @now and discarding unnecessary
+ * elements (for example, return only time if the date is today).
+ *
+ * Returns: a newly-allocated human readable string which represents @microsecs
+ */
 gchar *
 gl_util_timestamp_to_display (guint64 microsecs,
+                              GDateTime *now,
                               GlUtilClockFormat format)
 {
     GDateTime *datetime;
     GDateTime *local;
-    GDateTime *now;
     gchar *time = NULL;
 
     datetime = g_date_time_new_from_unix_utc (microsecs / G_TIME_SPAN_SECOND);
@@ -82,7 +126,6 @@ gl_util_timestamp_to_display (guint64 microsecs,
     }
 
     local = g_date_time_to_local (datetime);
-    now = g_date_time_new_now_local ();
 
     switch (format)
     {
@@ -142,7 +185,6 @@ gl_util_timestamp_to_display (guint64 microsecs,
 
     g_date_time_unref (datetime);
     g_date_time_unref (local);
-    g_date_time_unref (now);
 
     if (time == NULL)
     {
